==> pagseguro_sdk-0.0.3.tar.gz: android/src/main/kotlin/com/pagseguro/sdk/pagseguro_sdk/PagseguroSdkPlugin.kt <==
package com.pagseguro.sdk.pagseguro_sdk

import android.app.Activity
import android.content.Context
import android.os.Build
import android.os.Handler
import android.os.Looper
import android.renderscript.ScriptGroup
import io.flutter.Log
import androidx.annotation.NonNull;
import br.com.uol.pagseguro.plugpag.PlugPag.TYPE_CREDITO
import br.com.uol.pagseguro.plugpagservice.wrapper.*
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.INSTALLMENT_TYPE_PARC_COMPRADOR
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.RET_OK
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.TYPE_DEBITO
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.TYPE_VOUCHER
import br.com.uol.pagseguro.plugpagservice.wrapper.data.request.PlugPagBeepData
import br.com.uol.pagseguro.plugpagservice.wrapper.data.request.PlugPagBeepData.Companion.FREQUENCE_LEVEL_3

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.math.BigDecimal
import java.math.RoundingMode
import java.util.*
import kotlin.collections.HashMap

/** PagseguroSdkPlugin */
public class PagseguroSdkPlugin: FlutterPlugin, MethodCallHandler, ActivityAware, EventChannel.StreamHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var eventChannel: EventChannel
  private var eventChannelSink: EventChannel.EventSink? = null
  private var passwordMask = "";

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "pagseguro_sdk")
    channel.setMethodCallHandler(this)
    eventChannel = EventChannel(flutterPluginBinding.binaryMessenger, "pagseguro_events")
    eventChannel.setStreamHandler(this)
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  companion object {
    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "pagseguro_sdk")
      val plgin = PagseguroSdkPlugin()
      channel.setMethodCallHandler(plgin)
      val eventChannel = EventChannel(registrar.messenger(), "pagseguro_events")
      eventChannel.setStreamHandler(plgin)
      plgin.eventChannel = eventChannel
    }
  }


  private lateinit var plugPag: PlugPag
  private lateinit var appName: String
  private lateinit var appVersion: String
  private lateinit var activationCode: String
  private lateinit var context: Context
  private lateinit var activity: Activity
  private lateinit var handler: Handler
  val TAG = "PAGSEGURO";

  init {
    android.util.Log.d(TAG, "loading ...")
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    android.util.Log.d(TAG, "attached")
    activity = binding.activity
    context = activity.application.applicationContext
    handler = Handler(Looper.getMainLooper());
  }


  override fun onDetachedFromActivity() {
    Log.d(TAG, "detached")
    // TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
    Thread{
      try {
        plugPag.abort();
      }catch (err: java.lang.Exception) {}
    }.start()
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    // TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
  }

  override fun onDetachedFromActivityForConfigChanges() {
    //TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
  }

  override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
    Thread{
      try {
        plugPag.abort();
      }catch (err: java.lang.Exception) {}
    }.start()
  }



  override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
    Log.d(TAG, "create...: $call")
    Log.d(TAG, call.method)
    if(call.method == "getPlatformVersion" || call.method == "platformVersion"){
      result.success("ok");
    }else if(call.method == "getModel"){
      result.success(Build.MODEL);
    }else if(call.method == "initialize"){
      initialize(call, result)
    }else if(call.method == "startPayment"){
      startPayment(call, result)
    }else if(call.method == "listen") {
      Log.d(TAG, "listeing...");
    }else if(call.method == "getInstallments"){
      Log.d(TAG, "nice");
      getInstallments(call, result)
    }

  }

  fun initialize(call: MethodCall, result: MethodChannel.Result) {

    Thread {
      android.util.Log.d(TAG, "attached")
      io.flutter.Log.d("PAG_PLUGIN", "initialize")
      appName = call.argument<String>("appName")!!
      appVersion = call.argument<String>("appVersion")!!
      activationCode = call.argument<String>("activationCode")!!
      try {
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 1")
        plugPag = PlugPag(context, PlugPagAppIdentification(appName, appVersion))
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 2")
        plugPag.initializeAndActivatePinpad(PlugPagActivationData(activationCode))
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 3")
        activity.runOnUiThread { result.success(true) }
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 4")
        plugPag.beep(PlugPagBeepData(FREQUENCE_LEVEL_3, 500))
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 5")
      }catch (err: Exception){
        io.flutter.Log.d("PAG_PLUGIN", "error.......: " + err.message)
        try {
          activity.runOnUiThread { result.error("1234", "initializarion error", "") }
        }catch (err: java.lang.Exception) {

        }
      }
    }.start()

  }

  fun startPayment(call: MethodCall, result: MethodChannel.Result){

    Thread {

      Log.d(TAG, "startPaument")

      var amount = call.argument<Double>("amount")!!

      var installments = call.argument<Long>("installments")!!

      var type = call.argument<String>("type")!!

      var paymentId = call.argument<String>("paymentId")!!

      Log.d("payment", "dopayment")
      
      plugPag.setEventListener(object:  PlugPagEventListener {
        override fun onEvent(data: PlugPagEventData) {
          Log.d(".....payment", data.eventCode.toString());
          Log.d(".....payment", data.customMessage !!);
          if(data.eventCode == 17 || data.eventCode == 16) {
            Log.d("........payment", "keyboard activity detected");
            if (data.eventCode == 17) {
              if (passwordMask.length > 0) {
                passwordMask = passwordMask.substring(0, passwordMask.length - 1);
              }
            } else if (data.eventCode == 16) {
              passwordMask += "*";
            }
            Log.d("KEYBOARD", "actual mask:$passwordMask");
          }

          Log.d("....payment", "run onUithread");
          activity.runOnUiThread{
            if(eventChannelSink != null) {
              Log.d("....payment", "send shit");
              eventChannelSink?.success(createEvent(
                  data.eventCode.toString(),
                  data.customMessage !!,
                  passwordMask,
                false
              ))
            }
          }
        }
      })

      Log.d("....payment", "actual make the payment");

      var resultPAG = plugPag.doPayment(PlugPagPaymentData(
              if (type == "C") TYPE_CREDITO else (if (type == "D") TYPE_DEBITO else TYPE_VOUCHER)
              , Math.round(amount * 100).toInt(), INSTALLMENT_TYPE_PARC_COMPRADOR, installments.toInt(), paymentId + "00000", true))

      if(eventChannelSink != null) {
        activity.runOnUiThread {
          if (resultPAG.result == RET_OK) {
            eventChannelSink?.success(createEvent(
                    "OK",
                    "Pagamento aprovado",
                    "",
                    true
            ))
          } else {
            eventChannelSink?.success(createEvent(
                    "FAIL",
                    "Pagamento não aprovado",
                    passwordMask,
                    true
            ))
          }
        }
      }

      eventChannelSink = null
      passwordMask = ""

      Log.d("....payment", resultPAG.result.toString());
      Log.d("....payment", resultPAG.transactionCode + "....");
      Log.d("....payment", resultPAG.errorCode + "....");
      Log.d("....payment", resultPAG.message + "....");

      activity.runOnUiThread { result.success(resultPAG.result == RET_OK) }


    }.start();

  }

  override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
     Log.d("....payment", "onListen called ......... :)");
      this.eventChannelSink = events!!
  }

  override fun onCancel(arguments: Any?) {
    Log.d("....payment", "oncancel called ......... :)");
      this.eventChannelSink = null
    Thread{
      plugPag.abort();
    }.start()
  }

  fun createEvent(code: String, message: String, passwordMask: String, finished: Boolean): Map<String, Any>{
    var event = HashMap<String, Any>()
    event.put("code", code)
    event.put("message", message)
    event.put("mask", passwordMask)
    event.put("finished", finished)
    return event
  }

  fun getInstallments(call: MethodCall, result: MethodChannel.Result) {

    Thread {
      val list = ArrayList<Map<String, Any>>()
      Log.d("installments?", "calculate...")
      val resultInstallments= plugPag.calculateInstallments((call.argument<Double>("amount")!!.times(100)).toInt().toString());
      var i = 1;
      Log.d("installments?", "yup")
      resultInstallments.forEach {
        val a = HashMap<String, Any> ()
        a.put("installmentCount", i)
        a.put("installmentAmount", BigDecimal(it).divide(BigDecimal(100)).setScale(2, RoundingMode.HALF_EVEN).toDouble())
        a.put("installmentRaw", it)
        list.add(a);
        i++;
      }
      Log.d("installments?", "runOnUiThread")
      activity.runOnUiThread {
        Log.d("installments?", "success call")
        result.success(list);
      }
    }.start()
  }

}

==> pagseguro_sdk-0.0.4.tar.gz: android/src/main/kotlin/com/pagseguro/sdk/pagseguro_sdk/PagseguroSdkPlugin.kt <==
package com.pagseguro.sdk.pagseguro_sdk

import android.app.Activity
import android.content.Context
import android.os.Build
import android.os.Handler
import android.os.Looper
import android.renderscript.ScriptGroup
import io.flutter.Log
import androidx.annotation.NonNull;
import br.com.uol.pagseguro.plugpag.PlugPag.TYPE_CREDITO
import br.com.uol.pagseguro.plugpagservice.wrapper.*
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.INSTALLMENT_TYPE_PARC_COMPRADOR
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.RET_OK
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.TYPE_DEBITO
import br.com.uol.pagseguro.plugpagservice.wrapper.PlugPag.Companion.TYPE_VOUCHER
import br.com.uol.pagseguro.plugpagservice.wrapper.data.request.PlugPagBeepData
import br.com.uol.pagseguro.plugpagservice.wrapper.data.request.PlugPagBeepData.Companion.FREQUENCE_LEVEL_3

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.EventChannel
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar
import java.math.BigDecimal
import java.math.RoundingMode
import java.util.*
import kotlin.collections.HashMap

/** PagseguroSdkPlugin */
public class PagseguroSdkPlugin: FlutterPlugin, MethodCallHandler, ActivityAware, EventChannel.StreamHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private lateinit var channel : MethodChannel
  private lateinit var eventChannel: EventChannel
  private var eventChannelSink: EventChannel.EventSink? = null
  private var passwordMask = "";

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "pagseguro_sdk")
    channel.setMethodCallHandler(this)
    eventChannel = EventChannel(flutterPluginBinding.binaryMessenger, "pagseguro_events")
    eventChannel.setStreamHandler(this)
  }

  // This static function is optional and equivalent to onAttachedToEngine. It supports the old
  // pre-Flutter-1.12 Android projects. You are encouraged to continue supporting
  // plugin registration via this function while apps migrate to use the new Android APIs
  // post-flutter-1.12 via https://flutter.dev/go/android-project-migration.
  //
  // It is encouraged to share logic between onAttachedToEngine and registerWith to keep
  // them functionally equivalent. Only one of onAttachedToEngine or registerWith will be called
  // depending on the user's project. onAttachedToEngine or registerWith must both be defined
  // in the same class.
  companion object {

    const val EVENT_PROCESSING = "EVENT_PROCESSING";
    const val EVENT_PASSWORD_REQUESTED = "EVENT_PROCESSING";
    const val EVENT_PASSWORD_UPDATED = "EVENT_PASSWORD_UPDATED";
    const val EVENT_DECLINED = "EVENT_DECLINED";
    const val EVENT_APPROVED = "EVENT_APPROVED";
    const val EVENT_CANCELLED = "EVENT_CANCELLED";

    @JvmStatic
    fun registerWith(registrar: Registrar) {
      val channel = MethodChannel(registrar.messenger(), "pagseguro_sdk")
      val plgin = PagseguroSdkPlugin()
      channel.setMethodCallHandler(plgin)
      val eventChannel = EventChannel(registrar.messenger(), "pagseguro_events")
      eventChannel.setStreamHandler(plgin)
      plgin.eventChannel = eventChannel
    }
  }


  private lateinit var plugPag: PlugPag
  private lateinit var appName: String
  private lateinit var appVersion: String
  private lateinit var activationCode: String
  private lateinit var context: Context
  private lateinit var activity: Activity
  private lateinit var handler: Handler
  val TAG = "PAGSEGURO";

  init {
    android.util.Log.d(TAG, "loading ...")
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    android.util.Log.d(TAG, "attached")
    activity = binding.activity
    context = activity.application.applicationContext
    handler = Handler(Looper.getMainLooper());
  }


  override fun onDetachedFromActivity() {
    Log.d(TAG, "detached")
    // TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
    Thread{
      try {
        plugPag.abort();
      }catch (err: java.lang.Exception) {}
    }.start()
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    // TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
  }

  override fun onDetachedFromActivityForConfigChanges() {
    //TDO("not implemented") //To change body of created functions use File | Settings | File Templates.
  }

  override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
    Thread{
      try {
        plugPag.abort();
      }catch (err: java.lang.Exception) {}
    }.start()
  }



  override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
    Log.d(TAG, "create...: $call")
    Log.d(TAG, call.method)
    if(call.method == "getPlatformVersion" || call.method == "platformVersion"){
      result.success("ok");
    }else if(call.method == "getModel"){
      result.success(Build.MODEL);
    }else if(call.method == "initialize"){
      initialize(call, result)
    }else if(call.method == "startPayment"){
      startPayment(call, result)
    }else if(call.method == "listen") {
      Log.d(TAG, "listeing...");
    }else if(call.method == "getInstallments"){
      Log.d(TAG, "nice");
      getInstallments(call, result)
    }

  }

  fun initialize(call: MethodCall, result: MethodChannel.Result) {

    Thread {
      android.util.Log.d(TAG, "attached")
      io.flutter.Log.d("PAG_PLUGIN", "initialize")
      appName = call.argument<String>("appName")!!
      appVersion = call.argument<String>("appVersion")!!
      activationCode = call.argument<String>("activationCode")!!
      try {
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 1")
        plugPag = PlugPag(context, PlugPagAppIdentification(appName, appVersion))
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 2")
        plugPag.initializeAndActivatePinpad(PlugPagActivationData(activationCode))
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 3")
        activity.runOnUiThread { result.success(true) }
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 4")
        plugPag.beep(PlugPagBeepData(FREQUENCE_LEVEL_3, 500))
        io.flutter.Log.d("PAG_PLUGIN", "success ..... 5")
      }catch (err: Exception){
        io.flutter.Log.d("PAG_PLUGIN", "error.......: " + err.message)
        try {
          activity.runOnUiThread { result.error("1234", "initializarion error", "") }
        }catch (err: java.lang.Exception) {

        }
      }
    }.start()

  }

  fun startPayment(call: MethodCall, result: MethodChannel.Result){

    Thread {

      Log.d(TAG, "startPaument")

      var amount = call.argument<Double>("amount")!!

      var installments = call.argument<Long>("installments")!!

      var type = call.argument<String>("type")!!

      var paymentId = call.argument<String>("paymentId")!!

      Log.d("payment", "dopayment")
      
      plugPag.setEventListener(object:  PlugPagEventListener {
        override fun onEvent(data: PlugPagEventData) {
          var eventType = EVENT_PROCESSING;
          Log.d(".....payment", data.eventCode.toString());
          Log.d(".....payment", data.customMessage !!);
          if(data.eventCode == 17 || data.eventCode == 16) {
            eventType = EVENT_PASSWORD_UPDATED;
            Log.d("........payment", "keyboard activity detected");
            if (data.eventCode == 17) {
              if (passwordMask.length > 0) {
                passwordMask = passwordMask.substring(0, passwordMask.length - 1);
              }
            } else if (data.eventCode == 16) {
              passwordMask += "*";
            }
            Log.d("KEYBOARD", "actual mask:$passwordMask");
          }

          val message = data.customMessage !!

          if(message.startsWith("PROCESSANDO")){
            eventType = EVENT_PROCESSING;
          }else if(message.contains("DIGITE")){
            eventType = EVENT_PASSWORD_REQUESTED;
          }


          Log.d("....payment", "run onUithread");
          activity.runOnUiThread{
            if(eventChannelSink != null) {
              Log.d("....payment", "send shit");
              eventChannelSink?.success(createEvent(
                  data.eventCode.toString(),
                  data.customMessage !!,
                  passwordMask,
                false,
                  eventType
              ))
            }
          }
        }
      })

      Log.d("....payment", "actual make the payment");

      activity.runOnUiThread {
        eventChannelSink?.success(createEvent("initial", "Aguarde ..", "", false, EVENT_PROCESSING))
      }

      var resultPAG = plugPag.doPayment(PlugPagPaymentData(
              if (type == "C") TYPE_CREDITO else (if (type == "D") TYPE_DEBITO else TYPE_VOUCHER)
              , Math.round(amount * 100).toInt(), INSTALLMENT_TYPE_PARC_COMPRADOR, installments.toInt(), paymentId + "00000", true))

      if(eventChannelSink != null) {
        activity.runOnUiThread {
          if (resultPAG.result == RET_OK) {
            eventChannelSink?.success(createEvent(
                    "OK",
                    "Pagamento aprovado",
                    "",
                    true,
                    EVENT_APPROVED
            ))
          } else {
            eventChannelSink?.success(createEvent(
                    "FAIL",
                    "Pagamento não aprovado",
                    passwordMask,
                    true,
                    EVENT_DECLINED
            ))
          }
        }
      }

      eventChannelSink = null
      passwordMask = ""

      Log.d("....payment", resultPAG.result.toString());
      Log.d("....payment", resultPAG.transactionCode + "....");
      Log.d("....payment", resultPAG.errorCode + "....");
      Log.d("....payment", resultPAG.message + "....");

      activity.runOnUiThread { result.success(resultPAG.result == RET_OK) }

    }.start();

  }

  override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
     Log.d("....payment", "onListen called ......... :)");
      this.eventChannelSink = events!!
  }

  override fun onCancel(arguments: Any?) {
    Log.d("....payment", "oncancel called ......... :)");
      this.eventChannelSink = null
    Thread{
      plugPag.abort();
    }.start()
  }

  fun createEvent(code: String, message: String, passwordMask: String, finished: Boolean, eventType: String): Map<String, Any>{
    var event = HashMap<String, Any>()
    event.put("code", code)
    event.put("message", message)
    event.put("mask", passwordMask)
    event.put("finished", finished)
    event.put("type", eventType)
    return event
  }

  fun getInstallments(call: MethodCall, result: MethodChannel.Result) {

    Thread {
      val list = ArrayList<Map<String, Any>>()
      Log.d("installments?", "calculate...")
      val resultInstallments= plugPag.calculateInstallments((call.argument<Double>("amount")!!.times(100)).toInt().toString());
      var i = 1;
      Log.d("installments?", "yup")
      resultInstallments.forEach {
        val a = HashMap<String, Any> ()
        a.put("installmentCount", i)
        a.put("installmentAmount", BigDecimal(it).divide(BigDecimal(100)).setScale(2, RoundingMode.HALF_EVEN).toDouble())
        a.put("installmentRaw", it)
        list.add(a);
        i++;
      }
      Log.d("installments?", "runOnUiThread")
      activity.runOnUiThread {
        Log.d("installments?", "success call")
        result.success(list);
      }
    }.start()
  }

}
